==> jenkins-core-1.642.3-sources.jar: jenkins/slaves/systemInfo/Messages.java <==
// CHECKSTYLE:OFF

package jenkins.slaves.systemInfo;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code ThreadDumpSlaveInfo.DisplayName}: {@code Thread Dump}.
     * 
     * @return
     *     {@code Thread Dump}
     */
    public static String ThreadDumpSlaveInfo_DisplayName() {
        return holder.format("ThreadDumpSlaveInfo.DisplayName");
    }

    /**
     * Key {@code ThreadDumpSlaveInfo.DisplayName}: {@code Thread Dump}.
     * 
     * @return
     *     {@code Thread Dump}
     */
    public static Localizable _ThreadDumpSlaveInfo_DisplayName() {
        return new Localizable(holder, "ThreadDumpSlaveInfo.DisplayName");
    }

    /**
     * Key {@code ClassLoaderStatisticsSlaveInfo.DisplayName}: {@code Remote
     * Class Loader Statistics}.
     * 
     * @return
     *     {@code Remote Class Loader Statistics}
     */
    public static String ClassLoaderStatisticsSlaveInfo_DisplayName() {
        return holder.format("ClassLoaderStatisticsSlaveInfo.DisplayName");
    }

    /**
     * Key {@code ClassLoaderStatisticsSlaveInfo.DisplayName}: {@code Remote
     * Class Loader Statistics}.
     * 
     * @return
     *     {@code Remote Class Loader Statistics}
     */
    public static Localizable _ClassLoaderStatisticsSlaveInfo_DisplayName() {
        return new Localizable(holder, "ClassLoaderStatisticsSlaveInfo.DisplayName");
    }

    /**
     * Key {@code SystemPropertySlaveInfo.DisplayName}: {@code System
     * Properties}.
     * 
     * @return
     *     {@code System Properties}
     */
    public static String SystemPropertySlaveInfo_DisplayName() {
        return holder.format("SystemPropertySlaveInfo.DisplayName");
    }

    /**
     * Key {@code SystemPropertySlaveInfo.DisplayName}: {@code System
     * Properties}.
     * 
     * @return
     *     {@code System Properties}
     */
    public static Localizable _SystemPropertySlaveInfo_DisplayName() {
        return new Localizable(holder, "SystemPropertySlaveInfo.DisplayName");
    }

    /**
     * Key {@code EnvVarsSlaveInfo.DisplayName}: {@code Environment
     * Variables}.
     * 
     * @return
     *     {@code Environment Variables}
     */
    public static String EnvVarsSlaveInfo_DisplayName() {
        return holder.format("EnvVarsSlaveInfo.DisplayName");
    }

    /**
     * Key {@code EnvVarsSlaveInfo.DisplayName}: {@code Environment
     * Variables}.
     * 
     * @return
     *     {@code Environment Variables}
     */
    public static Localizable _EnvVarsSlaveInfo_DisplayName() {
        return new Localizable(holder, "EnvVarsSlaveInfo.DisplayName");
    }

}

==> jenkins-core-2.440.3-sources.jar: jenkins/slaves/systemInfo/Messages.java <==
// CHECKSTYLE:OFF

package jenkins.slaves.systemInfo;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;
import org.kohsuke.accmod.Restricted;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
@Restricted(org.kohsuke.accmod.restrictions.NoExternalUse.class)
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code SystemPropertySlaveInfo.DisplayName}: {@code System
     * Properties}.
     * 
     * @return
     *     {@code System Properties}
     */
    public static String SystemPropertySlaveInfo_DisplayName() {
        return holder.format("SystemPropertySlaveInfo.DisplayName");
    }

    /**
     * Key {@code SystemPropertySlaveInfo.DisplayName}: {@code System
     * Properties}.
     * 
     * @return
     *     {@code System Properties}
     */
    public static Localizable _SystemPropertySlaveInfo_DisplayName() {
        return new Localizable(holder, "SystemPropertySlaveInfo.DisplayName");
    }

    /**
     * Key {@code EnvVarsSlaveInfo.DisplayName}: {@code Environment
     * Variables}.
     * 
     * @return
     *     {@code Environment Variables}
     */
    public static String EnvVarsSlaveInfo_DisplayName() {
        return holder.format("EnvVarsSlaveInfo.DisplayName");
    }

    /**
     * Key {@code EnvVarsSlaveInfo.DisplayName}: {@code Environment
     * Variables}.
     * 
     * @return
     *     {@code Environment Variables}
     */
    public static Localizable _EnvVarsSlaveInfo_DisplayName() {
        return new Localizable(holder, "EnvVarsSlaveInfo.DisplayName");
    }

    /**
     * Key {@code ClassLoaderStatisticsSlaveInfo.DisplayName}: {@code Remote
     * Class Loader Statistics}.
     * 
     * @return
     *     {@code Remote Class Loader Statistics}
     */
    public static String ClassLoaderStatisticsSlaveInfo_DisplayName() {
        return holder.format("ClassLoaderStatisticsSlaveInfo.DisplayName");
    }

    /**
     * Key {@code ClassLoaderStatisticsSlaveInfo.DisplayName}: {@code Remote
     * Class Loader Statistics}.
     * 
     * @return
     *     {@code Remote Class Loader Statistics}
     */
    public static Localizable _ClassLoaderStatisticsSlaveInfo_DisplayName() {
        return new Localizable(holder, "ClassLoaderStatisticsSlaveInfo.DisplayName");
    }

    /**
     * Key {@code ThreadDumpSlaveInfo.DisplayName}: {@code Thread Dump}.
     * 
     * @return
     *     {@code Thread Dump}
     */
    public static String ThreadDumpSlaveInfo_DisplayName() {
        return holder.format("ThreadDumpSlaveInfo.DisplayName");
    }

    /**
     * Key {@code ThreadDumpSlaveInfo.DisplayName}: {@code Thread Dump}.
     * 
     * @return
     *     {@code Thread Dump}
     */
    public static Localizable _ThreadDumpSlaveInfo_DisplayName() {
        return new Localizable(holder, "ThreadDumpSlaveInfo.DisplayName");
    }

}
